==> igniteui-angular-charts-18.1.0.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicator = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
        bi() {
            return new RateOfChangeAndMomentumIndicator();
        }
        get_abm() {
            return new RateOfChangeAndMomentumIndicatorStrategy();
        }
        get abm() {
            return this.get_abm();
        }
        get_abz() {
            return RateOfChangeAndMomentumIndicator.$;
        }
        get abz() {
            return this.get_abz();
        }
        get ab7() {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.ab8));
        }
        set ab7(a) {
            this.h(RateOfChangeAndMomentumIndicator.ab8, a);
        }
        abs() {
            return this.ab7;
        }
        ab1(a) {
            this.ab7 = a;
        }
    }
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.ab8 = StrategyBasedIndicator.ab4(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
})();

==> igniteui-angular-charts-18.1.1.tgz: package/esm2015/lib/RateOfChangeAndMomentumIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { RateOfChangeAndMomentumIndicatorStrategy } from "./RateOfChangeAndMomentumIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let RateOfChangeAndMomentumIndicator = /*@__PURE__*/ (() => {
    class RateOfChangeAndMomentumIndicator extends StrategyBasedIndicator {
        bi() {
            return new RateOfChangeAndMomentumIndicator();
        }
        get_abn() {
            return new RateOfChangeAndMomentumIndicatorStrategy();
        }
        get abn() {
            return this.get_abn();
        }
        get_ab0() {
            return RateOfChangeAndMomentumIndicator.$;
        }
        get ab0() {
            return this.get_ab0();
        }
        get ab8() {
            return typeGetValue(this.c(RateOfChangeAndMomentumIndicator.ab9));
        }
        set ab8(a) {
            this.h(RateOfChangeAndMomentumIndicator.ab9, a);
        }
        abt() {
            return this.ab8;
        }
        ab2(a) {
            this.ab8 = a;
        }
    }
    RateOfChangeAndMomentumIndicator.$t = markType(RateOfChangeAndMomentumIndicator, 'RateOfChangeAndMomentumIndicator', StrategyBasedIndicator.$);
    RateOfChangeAndMomentumIndicator.ab9 = StrategyBasedIndicator.ab5(14, RateOfChangeAndMomentumIndicator.$);
    return RateOfChangeAndMomentumIndicator;
})();
